Learn R Programming

urlshorteneR (version 0.8.8)

bitly_LinksMetricsEncodersCount: Returns the number of users who have shortened a link.

Description

Returns the number of users who have shortened (encoded) a single Bitlink.

Usage

bitly_LinksMetricsEncodersCount(link, showRequestURL = FALSE)

Arguments

Value

aggregate_link - the aggregate (global) Bitlink for the provided Bitlink.

count - the number of bitly users who have shortened (encoded) this link.

See Also

http://dev.bitly.com/link_metrics.html#v3_link_encoders_count

Examples

Run this code
bitly_token <- bitly_auth(key = "", secret = "")
bitly_LinksMetricsEncodersCount(link = "http://bit.ly/DPetrov")

Run the code above in your browser using DataLab