Learn R Programming

urlshorteneR (version 0.8.8)

bitly_LinksMetricsReferringDomains: Returns metrics about the domains referring click traffic to a link.

Description

Returns metrics about the domains referring click traffic to a single Bitlink.

Usage

bitly_LinksMetricsReferringDomains(link, limit = 1000, unit = c("minute",
  "hour", "day", "week", "month"), units = -1, showRequestURL = FALSE)

Arguments

Value

clicks - the number of clicks referred from this domain.

domain - the domain referring clicks.

url - the complete URL of the domain referring clicks.

See Also

http://dev.bitly.com/link_metrics.html#v3_link_referring_domains

Examples

Run this code
bitly_token <- bitly_auth(key = "", secret = "")
bitly_LinksMetricsReferringDomains("http://bit.ly/DPetrov", unit = "day", units=-1, limit = 100)

Run the code above in your browser using DataLab