Learn R Programming

urlshorteneR (version 0.8.8)

bitly_UserMetricsClicks: Returns the aggregate number of clicks on all of the authenticated user's Bitlinks.

Description

See http://dev.bitly.com/user_metrics.html#v3_user_clicks

Usage

bitly_UserMetricsClicks(limit = 1000, unit = c("minute", "hour", "day",
  "week", "month"), units = -1, rollup = c("false", "true"),
  showRequestURL = FALSE)

Arguments

Value

dt - a unix timestamp representing the beginning of this unit.

day_start - a unix timestamp representing the beginning of the specified day (ONLY returned if unit is not specified).

clicks - the number of clicks on this user's links in the specified timeframe.

Examples

Run this code
bitly_token <- bitly_auth(key = "", secret = "")
bitly_UserMetricsClicks(unit = "day", units = -1, limit = 100, rollup = "true")
bitly_UserMetricsClicks(unit = "day", units = -1, limit = 100, rollup = "false")

Run the code above in your browser using DataLab