Learn R Programming

urlshorteneR (version 0.8.8)

bitly_UserMetricsReferringDomains: Returns aggregate metrics about the domains referring click traffic to all of the authenticated user's Bitlinks.

Description

If the user is a master (ent.) account, or is a subaccount with full_reports permission, the user may choose to view the metrics of any account belonging to the master account.

Usage

bitly_UserMetricsReferringDomains(limit = 1000, unit = c("minute", "hour",
  "day", "week", "month"), rollup = c("false", "true"), units = -1,
  login = NULL, exclude_social_networks = c("true", "false"),
  showRequestURL = FALSE)

Arguments

Value

clicks - the number of clicks referred from this URL.

referrer - the URL referring clicks.

See Also

See http://dev.bitly.com/user_metrics.html#v3_user_referring_domains

Examples

Run this code
bitly_token <- bitly_auth(key = "", secret = "")
bitly_UserMetricsReferringDomains(unit = "day", units = -1, limit = 100, rollup = "true")
bitly_UserMetricsReferringDomains(unit = "day", units = -1, limit = 100, rollup = "false")
bitly_UserMetricsReferringDomains(unit = "day", units = -1, limit = 100, 
exclude_social_networks = "false")
bitly_UserMetricsReferringDomains(unit = "day", units = -1, limit = 100, 
exclude_social_networks = "true")

Run the code above in your browser using DataLab