Learn R Programming

urlshorteneR (version 0.8.8)

googl_UserLinkHistory: Retrieves a list of URLs shortened by the authenticated user.

Description

returns a paginated list of information about short URLs created by a user, sorted in reverse chronological order. Each returned resource contains the short URL, long URL, creation timestamp, and status.

Usage

googl_UserLinkHistory(projection = "FULL", showRequestURL = FALSE)

Arguments

Value

totalItems - is an approximate number of items in the user's entire history.

nextPageToken - is an opaque string you can use to get the next page of history. It looks a lot like an ISO 8601 formatted date right now, but you should not count on that being true. The nextPageToken will be present on all but the last page

long_url - items contains the list of entries for the first "page" of the user's history, in order of descending creation time. The values for each entry are the same as specified in the Analytics section https://developers.google.com/url-shortener/v1/getting_started#url_analytics.

See Also

See https://developers.google.com/url-shortener/v1/url/list

See https://developers.google.com/url-shortener/v1/getting_started#history

Examples

Run this code
googl_token <- googl_auth(key = "", secret = "")
googl_UserLinkHistory(showRequestURL = TRUE)
googl_UserLinkHistory(projection = "FULL", showRequestURL = TRUE)

Run the code above in your browser using DataLab