link - the Bitlink specific to this user and this long_url.aggregate_link - the global bitly identifier for this long_url.
long_url - the original long URL.
archived - a true/false value indicating whether the user has archived this link.
private - a true/false value indicating whether the user has made this link private.
created_at - an integer unix epoch indicating when this link was shortened/encoded.
user_ts - a user-provided timestamp for when this link was shortened/encoded,
used for backfilling data.
modified_at - an integer unix epoch indicating when this link's metadata was last edited.
title - the title for this link.
note - the user-provided note, if set.
shares - a list of share actions (for the authenticated user only)
client_id - the oauth client ID of the app that shortened/saved this link on behalf of
the user. If expand_client_id is set to false (only currently supported), this will be a string
corresponding to the client_id of the encoding oauth application.